Buffer

Struct Buffer 

pub struct Buffer<K: AllocKind> { /* private fields */ }
The buffer that can be used by the Session.

Implementations

Source

impl<K: AllocKind> Buffer<K>

pub fn len(&self) -> usize

Returns the length of data region of the buffer.

pub fn frame_type(&self) -> Result<FrameType>

Retrieves the frame type of the buffer.

pub fn port(&self) -> Port

Retrieves the buffer’s source port.

pub fn as_slice(&self) -> Option<&[u8]>

Returns the buffer data as a slice.

pub fn as_slice_mut(&mut self) -> Option<&mut [u8]>

Returns the buffer data as a mutable slice.

pub fn io(&self) -> BufferIO<&'_ [u8], K>

Returns a wrapper for read-only operations.

pub fn io_mut(&mut self) -> BufferIO<&'_ mut [u8], K>

Returns a wrapper for read-write operations.

Source

impl Buffer<Tx>

pub fn set_port(&mut self, port: Port)

Sets the buffer’s destination port.

pub fn set_frame_type(&mut self, frame_type: FrameType)

Sets the frame type of the buffer.

pub fn set_tx_flags(&mut self, flags: TxFlags)

Sets TxFlags of a Tx buffer.

Source

impl Buffer<Rx>

pub async fn into_tx(self) -> Buffer<Tx>

Turns an rx buffer into a tx one.

pub fn rx_flags(&self) -> Result<RxFlags>

Retrieves RxFlags of an Rx Buffer.