SinglePartTxBuffer

Struct SinglePartTxBuffer 

pub struct SinglePartTxBuffer(/* private fields */);
A witness type that proves the buffer is backed by one part only and thus can be converted into &[u8].

Implementations

Source

impl SinglePartTxBuffer

pub fn new(buffer: Buffer<Tx>, len: usize) -> Option<Self>

Creates a new SinglePartTxBuffer from a Buffer<Tx> if it is backed by one part only.

pub fn into_inner(self) -> Buffer<Tx>

Converts back to a Tx buffer.