pub struct RxMetadata<'a> { /* private fields */ }Expand description
A guard for reading metadata on an Rx buffer.
Holds a shared borrow of the underlying descriptor (DescRef),
ensuring that atomic reference counting is performed only once when obtaining
and dropping this guard, rather than on every individual field access.
Implementations
Sourceimpl<'a> RxMetadata<'a>
impl<'a> RxMetadata<'a>
Sourcepub fn rx_checksum_offloading(&self) -> Option<ChecksumRxOffloading>
pub fn rx_checksum_offloading(&self) -> Option<ChecksumRxOffloading>
Retrieves the checksum offloading information.
Sourcepub fn frame_type(&self) -> Result<FrameType>
pub fn frame_type(&self) -> Result<FrameType>
Retrieves the frame type of the buffer.