pub struct TxMetadataMut<'a> { /* private fields */ }Expand description
A guard for mutating metadata on a Tx buffer.
Holds an exclusive borrow of the underlying descriptor (DescRefMut),
ensuring that atomic reference counting is performed only once when obtaining
and dropping this guard, rather than on every individual field update.
Implementations
Sourceimpl<'a> TxMetadataMut<'a>
impl<'a> TxMetadataMut<'a>
Sourcepub fn set_frame_type(&mut self, frame_type: FrameType)
pub fn set_frame_type(&mut self, frame_type: FrameType)
Sets the frame type of the buffer.
Sourcepub fn set_tx_flags(&mut self, flags: TxFlags)
pub fn set_tx_flags(&mut self, flags: TxFlags)
Sets TxFlags of a Tx buffer.
Sourcepub fn set_generic_csum_offload(&mut self, start: u16, offset: u16)
pub fn set_generic_csum_offload(&mut self, start: u16, offset: u16)
Sets the generic checksum offload metadata for this buffer.